==> netdata_1.11.1+dfsg.orig.tar.xz: netdata-1.11.1+dfsg/CONTRIBUTORS.md <==
<!--
SPDX-License-Identifier: GPL-3.0-or-later
-->

# netdata contributors license agreement

**Thank you for contributing to netdata!**

This agreement is part of the legal framework of the open-source ecosystem
that adds some red tape, but protects both the contributor and the project.

To understand why this is needed, please read [a well-written chapter from
Karl Fogel’s Producing Open Source Software on CLAs](https://producingoss.com/en/copyright-assignment.html).

By signing this agreement, you do not change your rights to use your own
contributions for any other purpose.

## copyright license

The Contributor (*you*) grants netdata Inc. a perpetual, worldwide, non-exclusive,
no-charge, royalty-free, irrevocable copyright license to reproduce,
prepare derivative works of, publicly display, publicly perform, sublicense,
and distribute his contributions and such derivative works.

## copyright transfer

The Contributor (*you*) hereby assigns netdata Inc. copyright in his
contributions, to be licensed under the same terms as the rest of the code.

> *Note: this means we may re-license netdata (your contributions included)
> any way we see fit, without asking your permission.
> Open-source licenses have significant differences and in our attempt to
> help netdata grow we may have to distribute it under a different license.
> For example, CNCF, the Cloud Native Computing Foundation, requires netdata
> to be licensed under Apache-2.0 for it to be accepted as a member of the
> Foundation. We want to be free to do it.*

## original work

The Contributor (*you*) represent that each of his contributions is his
original creation and that he is legally entitled to grant the above license.

> *Note: if you are committing third party code, please make sure the third party
> license or any other restrictions are also included with your commits.
> netdata includes many third party libraries and tools and this is not a
> problem, provided that the license of the third party code is compatible with
> the one we use for netdata.*

## signature

Since Sep 17th 2018, we use https://cla-assistant.io/netdata/netdata for signing the CLA, on all pull requests.
Old contributors can sign the CLA at any time using this link.

## HISTORICAL SIGNATURES
(they have been imported to https://cla-assistant.io/netdata/netdata already)

The Contributor (*you*) signs this agreement by adding his personal data in
this document and committing it to the project repo
(the same way contributions are submitted to the project).

By signing once, all contributions (past and future) of The Contributor (*you*),
are subject to this agreement.

> *Note: so you have to:*
> 1. add your github username and name in this file
> 2. commit it to the repo with a PR, using the same github username, or include this change in your first PR.

# netdata contributors

This is the list of contributors that have signed this agreement:

username|name|email (optional)
:--------:|:----:|:----------------
@lets00|Luís Eduardo|leduardo@lsd.ufcg.edu.br
@ktsaou|Costa Tsaousis|costa@tsaousis.gr
@tycho|Steven Noonan|steven@uplinklabs.net
@philwhineray|Phil Whineray|
@paulfantom|Paweł Krupa|pawel@krupa.net.pl
@Ferroin|Austin S. Hemmelgarn|ahferroin7@gmail.com
@glensc|Elan Ruusamäe|
@l2isbad|Ilya Mashchenko|ilyamaschenko@gmail.com
@rlefevre|Rémi Lefèvre|
@vlvkobal|Vladimir Kobal|vlad@prokk.net
@simonnagl|Simon Nagl|
@manosf|Emmanouil Fokas|manosf@protonmail.com
@user501254|Ashesh Singh|user501254@gmail.com
@t-h-e|Stefan Forstenlechner|
@facetoe|Facetoe|
@ntlug|Christopher Cox|ccox@endlessnow.com
@alonbl|Alon Bar-Lev|alon.barlev@gmail.com
@Wing924|Wei He|weihe924stephen@gmail.com
@NeonSludge|Kirill Buev|kirill.buev@gmx.com
@kmlucy|Kyle Lucy|kmlucy@gmail.com
@RicardoSette|Ricardo Sette|ricardosette@freebsdbrasil.com.br
@383c57|Shinichi Tagashira|
@davidak|David Kleuker|netdata-contributors+vyff@davidak.de
@ccremer|Christian Cremer|
@jimcooley|Jim Cooley|jim.cooley@healthvana.com
@Chocobo1|Mike Tzou|
@cosmix|Dimosthenis Kaponis|
@shadycuz|Levi Blaney|shadycuz+spam@gmail.com
@Flums|Philip Gabrielsen|philip@digno.no
@domschl|Dominik Schlösser|dominik.schloesser@gmail.com
@tioumen|Guillaume Hospital|
@arch273|Jacob Ayres
@x4FF3|David Fuellgraf|
@jasonwbarnett|Jason Barnett|
@ecowed|Ed Wade|
@wungad|Rob Man|
@rda0|Sven Mäder|maeder@phys.ethz.ch
@alibo|Ali Borhani|aliborhani1@gmail.com
@Nani-o|Sofiane Medjkoune|sofiane@medjkoune.fr
@n0guest|Evgeniy K.|ask@osshelp.ru
@amichelic|Adalbert Michelic|
@abalabahaha|abalabahaha|hi@abal.moe
@illes|Illes S.|
@plasticrake|Patrick Seal
@jonfairbanks|Jon Fairbanks
@pjz|Paul Jimenez|pj@place.org
@jgrossiord|Julien Grossiord|julien@grossiord.net
@pohzipohzi|Poh Zi How
@vladmovchan|Vladyslav Movchan|vladislav.movchan@gmail.com
@gmosx|George Moschovitis

==> netdata_1.12.0.orig.tar.xz: netdata-1.12.0/CONTRIBUTORS.md <==
<!--
SPDX-License-Identifier: GPL-3.0-or-later
-->

# netdata contributors license agreement

**Thank you for contributing to netdata!**

This agreement is part of the legal framework of the open-source ecosystem
that adds some red tape, but protects both the contributor and the project.

To understand why this is needed, please read [a well-written chapter from
Karl Fogel’s Producing Open Source Software on CLAs](https://producingoss.com/en/copyright-assignment.html).

By signing this agreement, you do not change your rights to use your own
contributions for any other purpose.

## copyright license

The Contributor (*you*) grants netdata Inc. a perpetual, worldwide, non-exclusive,
no-charge, royalty-free, irrevocable copyright license to reproduce,
prepare derivative works of, publicly display, publicly perform, sublicense,
and distribute his contributions and such derivative works.

## copyright transfer

The Contributor (*you*) hereby assigns netdata Inc. copyright in his
contributions, to be licensed under the same terms as the rest of the code.

> *Note: this means we may re-license netdata (your contributions included)
> any way we see fit, without asking your permission.
> Open-source licenses have significant differences and in our attempt to
> help netdata grow we may have to distribute it under a different license.
> For example, CNCF, the Cloud Native Computing Foundation, requires netdata
> to be licensed under Apache-2.0 for it to be accepted as a member of the
> Foundation. We want to be free to do it.*

## original work

The Contributor (*you*) represent that each of his contributions is his
original creation and that he is legally entitled to grant the above license.

> *Note: if you are committing third party code, please make sure the third party
> license or any other restrictions are also included with your commits.
> netdata includes many third party libraries and tools and this is not a
> problem, provided that the license of the third party code is compatible with
> the one we use for netdata.*

## signature

Since Sep 17th 2018, we use https://cla-assistant.io/netdata/netdata for signing the CLA, on all pull requests.
Old contributors can sign the CLA at any time using this link.

## HISTORICAL SIGNATURES
(they have been imported to https://cla-assistant.io/netdata/netdata already)

The Contributor (*you*) signs this agreement by adding his personal data in
this document and committing it to the project repo
(the same way contributions are submitted to the project).

By signing once, all contributions (past and future) of The Contributor (*you*),
are subject to this agreement.

> *Note: so you have to:*
> 1. add your github username and name in this file
> 2. commit it to the repo with a PR, using the same github username, or include this change in your first PR.

# netdata contributors

This is the list of contributors that have signed this agreement:

username|name|email (optional)
:--------:|:----:|:----------------
@lets00|Luís Eduardo|leduardo@lsd.ufcg.edu.br
@ktsaou|Costa Tsaousis|costa@tsaousis.gr
@tycho|Steven Noonan|steven@uplinklabs.net
@philwhineray|Phil Whineray|
@paulfantom|Paweł Krupa|pawel@krupa.net.pl
@Ferroin|Austin S. Hemmelgarn|ahferroin7@gmail.com
@glensc|Elan Ruusamäe|
@l2isbad|Ilya Mashchenko|ilyamaschenko@gmail.com
@rlefevre|Rémi Lefèvre|
@vlvkobal|Vladimir Kobal|vlad@prokk.net
@simonnagl|Simon Nagl|
@manosf|Emmanouil Fokas|manosf@protonmail.com
@user501254|Ashesh Singh|user501254@gmail.com
@t-h-e|Stefan Forstenlechner|
@facetoe|Facetoe|
@ntlug|Christopher Cox|ccox@endlessnow.com
@alonbl|Alon Bar-Lev|alon.barlev@gmail.com
@Wing924|Wei He|weihe924stephen@gmail.com
@NeonSludge|Kirill Buev|kirill.buev@gmx.com
@kmlucy|Kyle Lucy|kmlucy@gmail.com
@RicardoSette|Ricardo Sette|ricardosette@freebsdbrasil.com.br
@383c57|Shinichi Tagashira|
@davidak|David Kleuker|netdata-contributors+vyff@davidak.de
@ccremer|Christian Cremer|
@jimcooley|Jim Cooley|jim.cooley@healthvana.com
@Chocobo1|Mike Tzou|
@cosmix|Dimosthenis Kaponis|
@shadycuz|Levi Blaney|shadycuz+spam@gmail.com
@Flums|Philip Gabrielsen|philip@digno.no
@domschl|Dominik Schlösser|dominik.schloesser@gmail.com
@tioumen|Guillaume Hospital|
@arch273|Jacob Ayres
@x4FF3|David Fuellgraf|
@jasonwbarnett|Jason Barnett|
@ecowed|Ed Wade|
@wungad|Rob Man|
@rda0|Sven Mäder|maeder@phys.ethz.ch
@alibo|Ali Borhani|aliborhani1@gmail.com
@Nani-o|Sofiane Medjkoune|sofiane@medjkoune.fr
@n0guest|Evgeniy K.|ask@osshelp.ru
@amichelic|Adalbert Michelic|
@abalabahaha|abalabahaha|hi@abal.moe
@illes|Illes S.|
@plasticrake|Patrick Seal
@jonfairbanks|Jon Fairbanks
@pjz|Paul Jimenez|pj@place.org
@jgrossiord|Julien Grossiord|julien@grossiord.net
@pohzipohzi|Poh Zi How
@vladmovchan|Vladyslav Movchan|vladislav.movchan@gmail.com
@gmosx|George Moschovitis
@adherzog|Adam Herzog|adam@adamherzog.com

[![analytics](https://www.google-analytics.com/collect?v=1&aip=1&t=pageview&_s=1&ds=github&dr=https%3A%2F%2Fgithub.com%2Fnetdata%2Fnetdata&dl=https%3A%2F%2Fmy-netdata.io%2Fgithub%2FCONTRIBUTORS&_u=MAC~&cid=5792dfd7-8dc4-476b-af31-da2fdb9f93d2&tid=UA-64295674-3)]()
